==> zio-aws-chimesdkmessaging_2.13-5.17.158.3-sources.jar: zio/aws/chimesdkmessaging/model/SendChannelMessageRequest.scala <==
package zio.aws.chimesdkmessaging.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.chimesdkmessaging.model.primitives.{
  MessageAttributeName,
  ChimeArn,
  NonEmptyContent,
  ClientRequestToken,
  Metadata
}
import scala.jdk.CollectionConverters._
final case class SendChannelMessageRequest(
    channelArn: ChimeArn,
    content: NonEmptyContent,
    `type`: zio.aws.chimesdkmessaging.model.ChannelMessageType,
    persistence: zio.aws.chimesdkmessaging.model.ChannelMessagePersistenceType,
    metadata: Option[Metadata] = None,
    clientRequestToken: ClientRequestToken,
    chimeBearer: ChimeArn,
    pushNotification: Option[
      zio.aws.chimesdkmessaging.model.PushNotificationConfiguration
    ] = None,
    messageAttributes: Option[Map[
      MessageAttributeName,
      zio.aws.chimesdkmessaging.model.MessageAttributeValue
    ]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.chimesdkmessaging.model.SendChannelMessageRequest = {
    import SendChannelMessageRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.chimesdkmessaging.model.SendChannelMessageRequest
      .builder()
      .channelArn(ChimeArn.unwrap(channelArn): java.lang.String)
      .content(NonEmptyContent.unwrap(content): java.lang.String)
      .`type`(`type`.unwrap)
      .persistence(persistence.unwrap)
      .optionallyWith(
        metadata.map(value => Metadata.unwrap(value): java.lang.String)
      )(_.metadata)
      .clientRequestToken(
        ClientRequestToken.unwrap(clientRequestToken): java.lang.String
      )
      .chimeBearer(ChimeArn.unwrap(chimeBearer): java.lang.String)
      .optionallyWith(pushNotification.map(value => value.buildAwsValue()))(
        _.pushNotification
      )
      .optionallyWith(
        messageAttributes.map(value =>
          value
            .map({ case (key, value) =>
              (MessageAttributeName.unwrap(key): java.lang.String) -> value
                .buildAwsValue()
            })
            .asJava
        )
      )(_.messageAttributes)
      .build()
  }
  def asReadOnly
      : zio.aws.chimesdkmessaging.model.SendChannelMessageRequest.ReadOnly =
    zio.aws.chimesdkmessaging.model.SendChannelMessageRequest
      .wrap(buildAwsValue())
}
object SendChannelMessageRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.chimesdkmessaging.model.SendChannelMessageRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.chimesdkmessaging.model.SendChannelMessageRequest =
      zio.aws.chimesdkmessaging.model.SendChannelMessageRequest(
        channelArn,
        content,
        `type`,
        persistence,
        metadata.map(value => value),
        clientRequestToken,
        chimeBearer,
        pushNotification.map(value => value.asEditable),
        messageAttributes.map(value =>
          value.map({ case (key, value) =>
            key -> value.asEditable
          })
        )
      )
    def channelArn: ChimeArn
    def content: NonEmptyContent
    def `type`: zio.aws.chimesdkmessaging.model.ChannelMessageType
    def persistence
        : zio.aws.chimesdkmessaging.model.ChannelMessagePersistenceType
    def metadata: Option[Metadata]
    def clientRequestToken: ClientRequestToken
    def chimeBearer: ChimeArn
    def pushNotification: Option[
      zio.aws.chimesdkmessaging.model.PushNotificationConfiguration.ReadOnly
    ]
    def messageAttributes: Option[Map[
      MessageAttributeName,
      zio.aws.chimesdkmessaging.model.MessageAttributeValue.ReadOnly
    ]]
    def getChannelArn: ZIO[Any, Nothing, ChimeArn] = ZIO.succeed(channelArn)
    def getContent: ZIO[Any, Nothing, NonEmptyContent] = ZIO.succeed(content)
    def getType: ZIO[
      Any,
      Nothing,
      zio.aws.chimesdkmessaging.model.ChannelMessageType
    ] = ZIO.succeed(`type`)
    def getPersistence: ZIO[
      Any,
      Nothing,
      zio.aws.chimesdkmessaging.model.ChannelMessagePersistenceType
    ] = ZIO.succeed(persistence)
    def getMetadata: ZIO[Any, AwsError, Metadata] =
      AwsError.unwrapOptionField("metadata", metadata)
    def getClientRequestToken: ZIO[Any, Nothing, ClientRequestToken] =
      ZIO.succeed(clientRequestToken)
    def getChimeBearer: ZIO[Any, Nothing, ChimeArn] = ZIO.succeed(chimeBearer)
    def getPushNotification: ZIO[
      Any,
      AwsError,
      zio.aws.chimesdkmessaging.model.PushNotificationConfiguration.ReadOnly
    ] = AwsError.unwrapOptionField("pushNotification", pushNotification)
    def getMessageAttributes: ZIO[Any, AwsError, Map[
      MessageAttributeName,
      zio.aws.chimesdkmessaging.model.MessageAttributeValue.ReadOnly
    ]] = AwsError.unwrapOptionField("messageAttributes", messageAttributes)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.chimesdkmessaging.model.SendChannelMessageRequest
  ) extends zio.aws.chimesdkmessaging.model.SendChannelMessageRequest.ReadOnly {
    override val channelArn: ChimeArn =
      zio.aws.chimesdkmessaging.model.primitives.ChimeArn(impl.channelArn())
    override val content: NonEmptyContent =
      zio.aws.chimesdkmessaging.model.primitives.NonEmptyContent(impl.content())
    override val `type`: zio.aws.chimesdkmessaging.model.ChannelMessageType =
      zio.aws.chimesdkmessaging.model.ChannelMessageType.wrap(impl.`type`())
    override val persistence
        : zio.aws.chimesdkmessaging.model.ChannelMessagePersistenceType =
      zio.aws.chimesdkmessaging.model.ChannelMessagePersistenceType
        .wrap(impl.persistence())
    override val metadata: Option[Metadata] = scala
      .Option(impl.metadata())
      .map(value => zio.aws.chimesdkmessaging.model.primitives.Metadata(value))
    override val clientRequestToken: ClientRequestToken =
      zio.aws.chimesdkmessaging.model.primitives
        .ClientRequestToken(impl.clientRequestToken())
    override val chimeBearer: ChimeArn =
      zio.aws.chimesdkmessaging.model.primitives.ChimeArn(impl.chimeBearer())
    override val pushNotification: Option[
      zio.aws.chimesdkmessaging.model.PushNotificationConfiguration.ReadOnly
    ] = scala
      .Option(impl.pushNotification())
      .map(value =>
        zio.aws.chimesdkmessaging.model.PushNotificationConfiguration
          .wrap(value)
      )
    override val messageAttributes: Option[Map[
      MessageAttributeName,
      zio.aws.chimesdkmessaging.model.MessageAttributeValue.ReadOnly
    ]] = scala
      .Option(impl.messageAttributes())
      .map(value =>
        value.asScala
          .map({ case (key, value) =>
            zio.aws.chimesdkmessaging.model.primitives.MessageAttributeName(
              key
            ) -> zio.aws.chimesdkmessaging.model.MessageAttributeValue
              .wrap(value)
          })
          .toMap
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.chimesdkmessaging.model.SendChannelMessageRequest
  ): zio.aws.chimesdkmessaging.model.SendChannelMessageRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-chimesdkmessaging_2.13-5.17.201.2-sources.jar: zio/aws/chimesdkmessaging/model/SendChannelMessageRequest.scala <==
package zio.aws.chimesdkmessaging.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.chimesdkmessaging.model.primitives.{
  MessageAttributeName,
  ChimeArn,
  NonEmptyContent,
  ClientRequestToken,
  Metadata
}
import scala.jdk.CollectionConverters._
final case class SendChannelMessageRequest(
    channelArn: ChimeArn,
    content: NonEmptyContent,
    `type`: zio.aws.chimesdkmessaging.model.ChannelMessageType,
    persistence: zio.aws.chimesdkmessaging.model.ChannelMessagePersistenceType,
    metadata: Optional[Metadata] = Optional.Absent,
    clientRequestToken: ClientRequestToken,
    chimeBearer: ChimeArn,
    pushNotification: Optional[
      zio.aws.chimesdkmessaging.model.PushNotificationConfiguration
    ] = Optional.Absent,
    messageAttributes: Optional[Map[
      MessageAttributeName,
      zio.aws.chimesdkmessaging.model.MessageAttributeValue
    ]] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.chimesdkmessaging.model.SendChannelMessageRequest = {
    import SendChannelMessageRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.chimesdkmessaging.model.SendChannelMessageRequest
      .builder()
      .channelArn(ChimeArn.unwrap(channelArn): java.lang.String)
      .content(NonEmptyContent.unwrap(content): java.lang.String)
      .`type`(`type`.unwrap)
      .persistence(persistence.unwrap)
      .optionallyWith(
        metadata.map(value => Metadata.unwrap(value): java.lang.String)
      )(_.metadata)
      .clientRequestToken(
        ClientRequestToken.unwrap(clientRequestToken): java.lang.String
      )
      .chimeBearer(ChimeArn.unwrap(chimeBearer): java.lang.String)
      .optionallyWith(pushNotification.map(value => value.buildAwsValue()))(
        _.pushNotification
      )
      .optionallyWith(
        messageAttributes.map(value =>
          value
            .map({ case (key, value) =>
              (MessageAttributeName.unwrap(key): java.lang.String) -> value
                .buildAwsValue()
            })
            .asJava
        )
      )(_.messageAttributes)
      .build()
  }
  def asReadOnly
      : zio.aws.chimesdkmessaging.model.SendChannelMessageRequest.ReadOnly =
    zio.aws.chimesdkmessaging.model.SendChannelMessageRequest
      .wrap(buildAwsValue())
}
object SendChannelMessageRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.chimesdkmessaging.model.SendChannelMessageRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.chimesdkmessaging.model.SendChannelMessageRequest =
      zio.aws.chimesdkmessaging.model.SendChannelMessageRequest(
        channelArn,
        content,
        `type`,
        persistence,
        metadata.map(value => value),
        clientRequestToken,
        chimeBearer,
        pushNotification.map(value => value.asEditable),
        messageAttributes.map(value =>
          value.map({ case (key, value) =>
            key -> value.asEditable
          })
        )
      )
    def channelArn: ChimeArn
    def content: NonEmptyContent
    def `type`: zio.aws.chimesdkmessaging.model.ChannelMessageType
    def persistence
        : zio.aws.chimesdkmessaging.model.ChannelMessagePersistenceType
    def metadata: Optional[Metadata]
    def clientRequestToken: ClientRequestToken
    def chimeBearer: ChimeArn
    def pushNotification: Optional[
      zio.aws.chimesdkmessaging.model.PushNotificationConfiguration.ReadOnly
    ]
    def messageAttributes: Optional[Map[
      MessageAttributeName,
      zio.aws.chimesdkmessaging.model.MessageAttributeValue.ReadOnly
    ]]
    def getChannelArn: ZIO[Any, Nothing, ChimeArn] = ZIO.succeed(channelArn)
    def getContent: ZIO[Any, Nothing, NonEmptyContent] = ZIO.succeed(content)
    def getType: ZIO[
      Any,
      Nothing,
      zio.aws.chimesdkmessaging.model.ChannelMessageType
    ] = ZIO.succeed(`type`)
    def getPersistence: ZIO[
      Any,
      Nothing,
      zio.aws.chimesdkmessaging.model.ChannelMessagePersistenceType
    ] = ZIO.succeed(persistence)
    def getMetadata: ZIO[Any, AwsError, Metadata] =
      AwsError.unwrapOptionField("metadata", metadata)
    def getClientRequestToken: ZIO[Any, Nothing, ClientRequestToken] =
      ZIO.succeed(clientRequestToken)
    def getChimeBearer: ZIO[Any, Nothing, ChimeArn] = ZIO.succeed(chimeBearer)
    def getPushNotification: ZIO[
      Any,
      AwsError,
      zio.aws.chimesdkmessaging.model.PushNotificationConfiguration.ReadOnly
    ] = AwsError.unwrapOptionField("pushNotification", pushNotification)
    def getMessageAttributes: ZIO[Any, AwsError, Map[
      MessageAttributeName,
      zio.aws.chimesdkmessaging.model.MessageAttributeValue.ReadOnly
    ]] = AwsError.unwrapOptionField("messageAttributes", messageAttributes)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.chimesdkmessaging.model.SendChannelMessageRequest
  ) extends zio.aws.chimesdkmessaging.model.SendChannelMessageRequest.ReadOnly {
    override val channelArn: ChimeArn =
      zio.aws.chimesdkmessaging.model.primitives.ChimeArn(impl.channelArn())
    override val content: NonEmptyContent =
      zio.aws.chimesdkmessaging.model.primitives.NonEmptyContent(impl.content())
    override val `type`: zio.aws.chimesdkmessaging.model.ChannelMessageType =
      zio.aws.chimesdkmessaging.model.ChannelMessageType.wrap(impl.`type`())
    override val persistence
        : zio.aws.chimesdkmessaging.model.ChannelMessagePersistenceType =
      zio.aws.chimesdkmessaging.model.ChannelMessagePersistenceType
        .wrap(impl.persistence())
    override val metadata: Optional[Metadata] = zio.aws.core.internal
      .optionalFromNullable(impl.metadata())
      .map(value => zio.aws.chimesdkmessaging.model.primitives.Metadata(value))
    override val clientRequestToken: ClientRequestToken =
      zio.aws.chimesdkmessaging.model.primitives
        .ClientRequestToken(impl.clientRequestToken())
    override val chimeBearer: ChimeArn =
      zio.aws.chimesdkmessaging.model.primitives.ChimeArn(impl.chimeBearer())
    override val pushNotification: Optional[
      zio.aws.chimesdkmessaging.model.PushNotificationConfiguration.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.pushNotification())
      .map(value =>
        zio.aws.chimesdkmessaging.model.PushNotificationConfiguration
          .wrap(value)
      )
    override val messageAttributes: Optional[Map[
      MessageAttributeName,
      zio.aws.chimesdkmessaging.model.MessageAttributeValue.ReadOnly
    ]] = zio.aws.core.internal
      .optionalFromNullable(impl.messageAttributes())
      .map(value =>
        value.asScala
          .map({ case (key, value) =>
            zio.aws.chimesdkmessaging.model.primitives.MessageAttributeName(
              key
            ) -> zio.aws.chimesdkmessaging.model.MessageAttributeValue
              .wrap(value)
          })
          .toMap
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.chimesdkmessaging.model.SendChannelMessageRequest
  ): zio.aws.chimesdkmessaging.model.SendChannelMessageRequest.ReadOnly =
    new Wrapper(impl)
}
